# This file was auto-generated by Fern from our API Definition.

from ...core.api_error import ApiError
from ..types.method_not_allowed_response import MethodNotAllowedResponse


class MethodNotAllowed(ApiError):
    def __init__(self, body: MethodNotAllowedResponse):
        super().__init__(status_code=405, body=body)
